<?php
/*
  $Id: cm_i_featured_products.php

  Featured Products Phoenix Cart v2.2.5
  by @raiwa
  info@oscaddons.com
  www.oscaddons.com

  Copyright (c) 2021: Rainer Schmied - @raiwa

  CE Phoenix, E-Commerce made Easy
  https://phoenixcart.org

  Copyright (c) 2021 Phoenix Cart

  Released under the GNU General Public License
*/

  class cm_i_featured_products extends abstract_executable_module {

    const CONFIG_KEY_BASE = 'MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_';

    public function __construct() {
      parent::__construct(__FILE__);
      
      $this->description .= '<p>by @raiwa <u><a target="_blank" href="http://www.oscaddons.com">www.oscaddons.com</a></u></p>';
    }

    function execute() {

      require_once('includes/functions/featured.php');

      $content_width = (int)MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_CONTENT_WIDTH;
      $card_layout = IS_PRODUCT_PRODUCTS_DISPLAY_ROW;

      $featured_products_content = NULL;

      list($usec, $sec) = explode(' ', microtime());
      srand( (float) $sec + ((float) $usec * 100000) );
      $mtm= rand();

      $query = <<<'EOSQL'
SELECT DISTINCT p.*, pd.*, 
  IF (s.status, s.specials_new_products_price, NULL) AS specials_new_products_price,
  IF(s.status, s.specials_new_products_price, p.products_price) AS final_price,
  p.products_quantity as in_stock, 
  IF(s.status, 1, 0) AS is_special
EOSQL
      ;

      if (MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_SHOW_DESCRIPTION == 'True') {
        $query .= sprintf(<<<'EOSQL'
, SUBSTRING_INDEX(pd.products_description, " ", %s) AS products_description
EOSQL
      , MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_DESCRIPTION_LENGTH);
      
      }
      
      $query .= sprintf(<<<'EOSQL'
  FROM products p 
    LEFT JOIN featured f 
      ON p.products_id = f.products_id
    LEFT JOIN specials s 
      ON p.products_id = s.products_id
    LEFT JOIN products_description pd 
      ON p.products_id = pd.products_id 
      AND pd.language_id = %s
  WHERE p.products_status = '1' 
    AND f.status = '1'
EOSQL
      , (int)$_SESSION['languages_id']);

      if ( defined('MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_SPECIALS_ONLY') && MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_SPECIALS_ONLY == 'true' ) {
        $query .= <<<'EOSQL'
  AND s.status = '1'
EOSQL
      ;
      }
      $query .= sprintf(<<<'EOSQL'
  ORDER BY rand(' . $mtm . ') DESC 
  LIMIT %s
EOSQL
      , MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_CONTENT_LIMIT);

      $featured_products_query = tep_db_query($query);
      $num_rows = mysqli_num_rows($featured_products_query);
      if (!$num_rows) {
        return;
      }

      $tpl_data = [ 'group' => $this->group, 'file' => __FILE__ ];
      include 'includes/modules/content/cm_template.php';

    }

    protected function get_parameters() {
      return [
        'MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_VERSION_INSTALLED' => [
          'title' => 'Current Version',
          'value' => '2.2.3',
          'desc' => 'Version info. It is read only',
          'set_func' => 'cm_i_featured_products::readonly(',
        ],
        'MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_STATUS' => [
          'title' => 'Enable Featured Products Module',
          'value' => 'True',
          'desc' => 'Do you want to enable this module?',
          'set_func' => "tep_cfg_select_option(['True', 'False'], ",
        ],
        'MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_CONTENT_WIDTH' => [
          'title' => 'Content Width',
          'value' => '12',
          'desc' => 'What width container should the content be shown in? (12 = full width, 6 = half width).',
          'set_func' => "tep_cfg_select_option(['12', '11', '10', '9', '8', '7', '6', '5', '4', '3', '2', '1'], ",
        ],
        'MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_SORT_ORDER' => [
          'title' => 'Sort Order',
          'value' => '300',
          'desc' => 'Sort order of display. Lowest is displayed first.',
        ],
        'MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_CONTENT_LIMIT' => [
          'title' => 'Number of Products',
          'value' => '6',
          'desc' => 'Maximum Number of products that should show in this module?',
        ],
        'MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_SHOW_DESCRIPTION' => [
          'title' => 'Show the product description',
          'value' => 'False',
          'desc' => 'Show the product description in the Featured Products module?',
          'set_func' => "tep_cfg_select_option(['True', 'False'], ",
        ],
        'MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_DESCRIPTION_LENGTH' => [
          'title' => 'Maximum description length',
          'value' => '25',
          'desc' => 'The number of words (to the nearest word) of the description to display in the Featured Products module',
        ],
        'MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_SPECIALS_ONLY' => [
          'title' => 'Specials Only When Displaying Featured Products',
          'value' => 'False',
          'desc' => 'Set to true or false in order to display only on specials featured products.',
          'set_func' => "tep_cfg_select_option(['True', 'False'], ",
        ],
        'MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_SHOW_BUTTON' => [
          'title' => 'Show the product MORE button',
          'value' => 'True',
          'desc' => 'Show the MORE button in the Featured Products module?',
          'set_func' => "tep_cfg_select_option(['True', 'False'], ",
        ],
        'MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_DELETE_TABLES' => [
          'title' => 'Delete auto created tables on module Remove',
          'value' => 'False',
          'desc' => 'Do you want to remove the tables that where created during installing this module?<br><i>Note: all the created data will be deleted</i>.',
          'set_func' => "tep_cfg_select_option(['True', 'False'], ",
        ],
      ];
    }

    function install($parameter_key = null) {
      parent::install($parameter_key);
      
      tep_db_query(<<<'EOSQL'
CREATE TABLE IF NOT EXISTS featured (
  featured_id int(11) NOT NULL auto_increment,
  products_id int(11) NOT NULL default '0',
  featured_date_added datetime default NULL,
  featured_last_modified datetime default NULL,
  expires_date datetime default NULL,
  date_status_change datetime default NULL,
  status int(1) default '1',
  PRIMARY KEY  (featured_id),
  KEY idx_products_id (products_id)
  ) 
DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci AUTO_INCREMENT=1 ;
EOSQL
      );

  }

    function remove($parameter_key = null) {
      parent::remove($parameter_key);

      if ( defined('MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_DELETE_TABLES') && MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_DELETE_TABLES == 'True' ) {
        tep_db_query(<<<'EOSQL'
DROP TABLE IF EXISTS featured
EOSQL
        );

      }
    }
    
    public static function readonly($value) {
      return $value;
    }

  }
